@@ -78,22 +78,25 @@ class View(caching.Memoizable):
                 spec[pagination] = input_spec[pagination]
                 break
 
-        self._order_by = spec.get('order', 'newest')
+        self.spec = spec.copy()
 
-        self.spec = spec
+        self._order_by = spec.pop('order', 'newest').lower()
 
         if 'start' in spec and paginated:
             if self._order_by == 'oldest':
-                self.spec['first'] = self.spec['start']
+                spec['first'] = spec['start']
             elif self._order_by == 'newest':
-                self.spec['last'] = self.spec['start']
+                spec['last'] = spec['start']
+        spec.pop('start', None)
+
+        count = spec.pop('count', None)
 
         self._entries = queries.build_query(
             spec).order_by(*queries.ORDER_BY[self._order_by])
 
         if self.spec.get('date') is not None:
             _, self.type, _ = utils.parse_date(self.spec['date'])
-        elif 'count' in self.spec:
+        elif count is not None:
             self.type = 'count'
         else:
             self.type = ''
@@ -173,7 +176,7 @@ class View(caching.Memoizable):
     @cached_property
     def deleted(self) -> typing.List[Entry]:
         """ Gets the deleted entries from the view """
-        query = queries.build_query({**self.spec,
+        query = queries.build_query({**self.query_spec,
                                      'future': False,
                                      '_deleted': True})
         if self.spec.get('count'):
@@ -406,6 +409,16 @@ class View(caching.Memoizable):
         # we're not paginating
         return None, None
 
+    @property
+    def query_spec(self):
+        """ Get the view spec in a queryable form """
+        return self.filter_query_spec(self.spec)
+
+    @staticmethod
+    def filter_query_spec(spec: ViewSpec):
+        """ Filter out query parameters that are view-specific """
+        return {k: v for k, v in spec.items() if k not in ('order', 'count')}
+
     def _get_date_pagination(self,
                              base: ViewSpec
                              ) -> typing.Tuple[typing.Optional['View'], typing.Optional['View']]:
@@ -413,7 +426,8 @@ class View(caching.Memoizable):
         date, interval, date_format = utils.parse_date(self.spec['date'])
         start_date, end_date = date.span(interval)
 
-        base_query = queries.build_query(base)
+        base_query = queries.build_query(self.filter_query_spec(base))
+
         oldest_neighbor = base_query.filter(lambda e: e.local_date < start_date.datetime)\
             .order_by(*queries.ORDER_BY['newest']).first()
         newest_neighbor = base_query.filter(lambda e: e.local_date > end_date.datetime)\
@@ -425,13 +439,11 @@ class View(caching.Memoizable):
         if newest_neighbor:
             newer_date = newest_neighbor.display_date
             newer_view = View.load({**base,
-                                    'order': self._order_by,
                                     'date': arrow.get(newer_date).format(date_format)})
 
         if oldest_neighbor:
             older_date = oldest_neighbor.display_date
             older_view = View.load({**base,
-                                    'order': self._order_by,
                                     'date': arrow.get(older_date).format(date_format)})
 
         return older_view, newer_view
